<?php

namespace Litecms\CouponCode\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\CouponCode\Http\Requests\CouponCodeRequest;
use Litecms\CouponCode\Models\CouponCode;

/**
 * Admin web controller class.
 */
class CouponCodeWorkflowController extends BaseController
{

    /**
     * Workflow controller function for coupon_code.
     *
     * @param Model   $coupon_code
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CouponCodeRequest $request, CouponCode $coupon_code, $step)
    {

        try {

            $coupon_code->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('coupon_code::coupon_code.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/coupon_code/coupon_code/' . $coupon_code->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/coupon_code/coupon_code/' . $coupon_code->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for coupon_code.
     *
     * @param Model   $coupon_code
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(CouponCode $coupon_code, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $coupon_code->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('coupon_code::coupon_code.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('coupon_code::admin.coupon_code.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('coupon_code::admin.coupon_code.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('coupon_code::admin.coupon_code.message', $data)->render();

        }

    }
}
